# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: graph_description.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='graph_description.proto',
  package='graph_description',
  syntax='proto3',
  serialized_pb=_b('\n\x17graph_description.proto\x12\x11graph_description\x1a\x1egoogle/protobuf/wrappers.proto\"\x97\x01\n\x07Session\x12\x1e\n\x16primary_key_properties\x18\x01 \x03(\t\x12%\n\x1dprimary_key_requires_asset_id\x18\x02 \x01(\x08\x12\x14\n\x0c\x63reated_time\x18\x03 \x01(\x04\x12\x16\n\x0elast_seen_time\x18\x04 \x01(\x04\x12\x17\n\x0fterminated_time\x18\x05 \x01(\x04\"O\n\x06Static\x12\x1e\n\x16primary_key_properties\x18\x01 \x03(\t\x12%\n\x1dprimary_key_requires_asset_id\x18\x02 \x01(\x08\"t\n\nIdStrategy\x12-\n\x07session\x18\x01 \x01(\x0b\x32\x1a.graph_description.SessionH\x00\x12+\n\x06static\x18\x02 \x01(\x0b\x32\x19.graph_description.StaticH\x00\x42\n\n\x08strategy\"9\n\x04Host\x12\x12\n\x08hostname\x18\x01 \x01(\tH\x00\x12\x12\n\x08\x61sset_id\x18\x02 \x01(\tH\x00\x42\t\n\x07host_id\"\x84\x05\n\x04Node\x12.\n\nasset_node\x18\x01 \x01(\x0b\x32\x18.graph_description.AssetH\x00\x12\x32\n\x0cprocess_node\x18\x02 \x01(\x0b\x32\x1a.graph_description.ProcessH\x00\x12,\n\tfile_node\x18\x03 \x01(\x0b\x32\x17.graph_description.FileH\x00\x12\x37\n\x0fip_address_node\x18\x04 \x01(\x0b\x32\x1c.graph_description.IpAddressH\x00\x12X\n process_outbound_connection_node\x18\x05 \x01(\x0b\x32,.graph_description.ProcessOutboundConnectionH\x00\x12V\n\x1fprocess_inbound_connection_node\x18\x06 \x01(\x0b\x32+.graph_description.ProcessInboundConnectionH\x00\x12\x31\n\x0cip_port_node\x18\x07 \x01(\x0b\x32\x19.graph_description.IpPortH\x00\x12G\n\x17network_connection_node\x18\x08 \x01(\x0b\x32$.graph_description.NetworkConnectionH\x00\x12=\n\x12ip_connection_node\x18\t \x01(\x0b\x32\x1f.graph_description.IpConnectionH\x00\x12\x36\n\x0c\x64ynamic_node\x18\n \x01(\x0b\x32\x1e.graph_description.DynamicNodeH\x00\x42\x0c\n\nwhich_node\"\xe7\x01\n\x05\x41sset\x12\x10\n\x08node_key\x18\x01 \x01(\t\x12.\n\x08\x61sset_id\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12.\n\x08hostname\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x31\n\x0bmac_address\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x1c\n\x14\x66irst_seen_timestamp\x18\x05 \x01(\x04\x12\x1b\n\x13last_seen_timestamp\x18\x06 \x01(\x04\"\xc7\x01\n\x0cIpConnection\x12\x10\n\x08node_key\x18\x01 \x01(\t\x12\x16\n\x0esrc_ip_address\x18\x02 \x01(\t\x12\x16\n\x0e\x64st_ip_address\x18\x03 \x01(\t\x12\x10\n\x08protocol\x18\x04 \x01(\t\x12\x19\n\x11\x63reated_timestamp\x18\x05 \x01(\x04\x12\x1c\n\x14terminated_timestamp\x18\x06 \x01(\x04\x12\x1b\n\x13last_seen_timestamp\x18\x07 \x01(\x04\x12\r\n\x05state\x18\x08 \x01(\r\"\xf0\x01\n\x11NetworkConnection\x12\x10\n\x08node_key\x18\x01 \x01(\t\x12\x16\n\x0esrc_ip_address\x18\x02 \x01(\t\x12\x16\n\x0e\x64st_ip_address\x18\x03 \x01(\t\x12\x10\n\x08protocol\x18\x04 \x01(\t\x12\x10\n\x08src_port\x18\x05 \x01(\r\x12\x10\n\x08\x64st_port\x18\x06 \x01(\r\x12\x19\n\x11\x63reated_timestamp\x18\x07 \x01(\x04\x12\x1c\n\x14terminated_timestamp\x18\x08 \x01(\x04\x12\x1b\n\x13last_seen_timestamp\x18\t \x01(\x04\x12\r\n\x05state\x18\n \x01(\r\"N\n\x06IpPort\x12\x10\n\x08node_key\x18\x01 \x01(\t\x12\x12\n\nip_address\x18\x02 \x01(\t\x12\x0c\n\x04port\x18\x03 \x01(\r\x12\x10\n\x08protocol\x18\x04 \x01(\t\"\xa6\x02\n\x19ProcessOutboundConnection\x12\x10\n\x08node_key\x18\x01 \x01(\t\x12.\n\x08\x61sset_id\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12.\n\x08hostname\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\r\n\x05state\x18\x04 \x01(\r\x12\x19\n\x11\x63reated_timestamp\x18\x05 \x01(\x04\x12\x1c\n\x14terminated_timestamp\x18\x06 \x01(\x04\x12\x1b\n\x13last_seen_timestamp\x18\x07 \x01(\x04\x12\x0c\n\x04port\x18\x08 \x01(\r\x12\x12\n\nip_address\x18\t \x01(\t\x12\x10\n\x08protocol\x18\n \x01(\t\"\xa5\x02\n\x18ProcessInboundConnection\x12\x10\n\x08node_key\x18\x01 \x01(\t\x12.\n\x08\x61sset_id\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12.\n\x08hostname\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\r\n\x05state\x18\x04 \x01(\r\x12\x19\n\x11\x63reated_timestamp\x18\x05 \x01(\x04\x12\x1c\n\x14terminated_timestamp\x18\x06 \x01(\x04\x12\x1b\n\x13last_seen_timestamp\x18\x07 \x01(\x04\x12\x0c\n\x04port\x18\x08 \x01(\r\x12\x12\n\nip_address\x18\t \x01(\t\x12\x10\n\x08protocol\x18\n \x01(\t\"\xd8\x02\n\x07Process\x12\x10\n\x08node_key\x18\x01 \x01(\t\x12.\n\x08\x61sset_id\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12.\n\x08hostname\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\r\n\x05state\x18\x04 \x01(\r\x12\x12\n\nprocess_id\x18\x05 \x01(\x04\x12\x14\n\x0cprocess_guid\x18\x06 \x01(\t\x12\x19\n\x11\x63reated_timestamp\x18\x07 \x01(\x04\x12\x1c\n\x14terminated_timestamp\x18\x08 \x01(\x04\x12\x1b\n\x13last_seen_timestamp\x18\t \x01(\x04\x12\x14\n\x0cprocess_name\x18\n \x01(\t\x12\x1c\n\x14process_command_line\x18\x0b \x01(\t\x12\x18\n\x10operating_system\x18\x0c \x01(\t\"\x9e\x04\n\x04\x46ile\x12\x10\n\x08node_key\x18\x01 \x01(\t\x12.\n\x08\x61sset_id\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12.\n\x08hostname\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\r\n\x05state\x18\x04 \x01(\r\x12\x19\n\x11\x63reated_timestamp\x18\x05 \x01(\x04\x12\x19\n\x11\x64\x65leted_timestamp\x18\x06 \x01(\x04\x12\x1b\n\x13last_seen_timestamp\x18\x07 \x01(\x04\x12\x11\n\tfile_name\x18\x08 \x01(\t\x12\x11\n\tfile_path\x18\t \x01(\t\x12\x16\n\x0e\x66ile_extension\x18\n \x01(\t\x12\x16\n\x0e\x66ile_mime_type\x18\x0b \x01(\t\x12\x11\n\tfile_size\x18\x0c \x01(\x04\x12\x14\n\x0c\x66ile_version\x18\r \x01(\t\x12\x18\n\x10\x66ile_description\x18\x0e \x01(\t\x12\x14\n\x0c\x66ile_product\x18\x0f \x01(\t\x12\x14\n\x0c\x66ile_company\x18\x10 \x01(\t\x12\x16\n\x0e\x66ile_directory\x18\x11 \x01(\t\x12\x12\n\nfile_inode\x18\x12 \x01(\x04\x12\x17\n\x0f\x66ile_hard_links\x18\x13 \x01(\x04\x12\x10\n\x08md5_hash\x18\x14 \x01(\t\x12\x11\n\tsha1_hash\x18\x15 \x01(\t\x12\x13\n\x0bsha256_hash\x18\x16 \x01(\t\"l\n\tIpAddress\x12\x10\n\x08node_key\x18\x01 \x01(\t\x12\x12\n\nip_address\x18\x02 \x01(\t\x12\x1c\n\x14\x66irst_seen_timestamp\x18\x03 \x01(\x04\x12\x1b\n\x13last_seen_timestamp\x18\x04 \x01(\x04\"T\n\x0cNodeProperty\x12\x11\n\x07intprop\x18\x01 \x01(\x03H\x00\x12\x12\n\x08uintprop\x18\x02 \x01(\x04H\x00\x12\x11\n\x07strprop\x18\x03 \x01(\tH\x00\x42\n\n\x08property\"\x9e\x03\n\x0b\x44ynamicNode\x12\x42\n\nproperties\x18\x01 \x03(\x0b\x32..graph_description.DynamicNode.PropertiesEntry\x12\x10\n\x08node_key\x18\x02 \x01(\t\x12\x11\n\tnode_type\x18\x03 \x01(\t\x12\x0f\n\x07seen_at\x18\x04 \x01(\x04\x12.\n\x08\x61sset_id\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12.\n\x08hostname\x18\x06 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12-\n\x07host_ip\x18\x07 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x32\n\x0bid_strategy\x18\x08 \x03(\x0b\x32\x1d.graph_description.IdStrategy\x1aR\n\x0fPropertiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12.\n\x05value\x18\x02 \x01(\x0b\x32\x1f.graph_description.NodeProperty:\x02\x38\x01\"2\n\x04\x45\x64ge\x12\x0c\n\x04\x66rom\x18\x01 \x01(\t\x12\n\n\x02to\x18\x02 \x01(\t\x12\x10\n\x08\x65\x64geName\x18\x03 \x01(\t\"2\n\x08\x45\x64geList\x12&\n\x05\x65\x64ges\x18\x01 \x03(\x0b\x32\x17.graph_description.Edge\"\x94\x02\n\x05Graph\x12\x32\n\x05nodes\x18\x01 \x03(\x0b\x32#.graph_description.Graph.NodesEntry\x12\x32\n\x05\x65\x64ges\x18\x02 \x03(\x0b\x32#.graph_description.Graph.EdgesEntry\x12\x11\n\ttimestamp\x18\x03 \x01(\x04\x1a\x45\n\nNodesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12&\n\x05value\x18\x02 \x01(\x0b\x32\x17.graph_description.Node:\x02\x38\x01\x1aI\n\nEdgesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12*\n\x05value\x18\x02 \x01(\x0b\x32\x1b.graph_description.EdgeList:\x02\x38\x01\"A\n\x12GeneratedSubgraphs\x12+\n\tsubgraphs\x18\x01 \x03(\x0b\x32\x18.graph_description.Graphb\x06proto3')
  ,
  dependencies=[google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)




_SESSION = _descriptor.Descriptor(
  name='Session',
  full_name='graph_description.Session',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='primary_key_properties', full_name='graph_description.Session.primary_key_properties', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='primary_key_requires_asset_id', full_name='graph_description.Session.primary_key_requires_asset_id', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='created_time', full_name='graph_description.Session.created_time', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='last_seen_time', full_name='graph_description.Session.last_seen_time', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='terminated_time', full_name='graph_description.Session.terminated_time', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=79,
  serialized_end=230,
)


_STATIC = _descriptor.Descriptor(
  name='Static',
  full_name='graph_description.Static',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='primary_key_properties', full_name='graph_description.Static.primary_key_properties', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='primary_key_requires_asset_id', full_name='graph_description.Static.primary_key_requires_asset_id', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=232,
  serialized_end=311,
)


_IDSTRATEGY = _descriptor.Descriptor(
  name='IdStrategy',
  full_name='graph_description.IdStrategy',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='session', full_name='graph_description.IdStrategy.session', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='static', full_name='graph_description.IdStrategy.static', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='strategy', full_name='graph_description.IdStrategy.strategy',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=313,
  serialized_end=429,
)


_HOST = _descriptor.Descriptor(
  name='Host',
  full_name='graph_description.Host',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='hostname', full_name='graph_description.Host.hostname', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='asset_id', full_name='graph_description.Host.asset_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='host_id', full_name='graph_description.Host.host_id',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=431,
  serialized_end=488,
)


_NODE = _descriptor.Descriptor(
  name='Node',
  full_name='graph_description.Node',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='asset_node', full_name='graph_description.Node.asset_node', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='process_node', full_name='graph_description.Node.process_node', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='file_node', full_name='graph_description.Node.file_node', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='ip_address_node', full_name='graph_description.Node.ip_address_node', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='process_outbound_connection_node', full_name='graph_description.Node.process_outbound_connection_node', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='process_inbound_connection_node', full_name='graph_description.Node.process_inbound_connection_node', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='ip_port_node', full_name='graph_description.Node.ip_port_node', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='network_connection_node', full_name='graph_description.Node.network_connection_node', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='ip_connection_node', full_name='graph_description.Node.ip_connection_node', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='dynamic_node', full_name='graph_description.Node.dynamic_node', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='which_node', full_name='graph_description.Node.which_node',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=491,
  serialized_end=1135,
)


_ASSET = _descriptor.Descriptor(
  name='Asset',
  full_name='graph_description.Asset',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='node_key', full_name='graph_description.Asset.node_key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='asset_id', full_name='graph_description.Asset.asset_id', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='hostname', full_name='graph_description.Asset.hostname', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='mac_address', full_name='graph_description.Asset.mac_address', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='first_seen_timestamp', full_name='graph_description.Asset.first_seen_timestamp', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='last_seen_timestamp', full_name='graph_description.Asset.last_seen_timestamp', index=5,
      number=6, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1138,
  serialized_end=1369,
)


_IPCONNECTION = _descriptor.Descriptor(
  name='IpConnection',
  full_name='graph_description.IpConnection',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='node_key', full_name='graph_description.IpConnection.node_key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='src_ip_address', full_name='graph_description.IpConnection.src_ip_address', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='dst_ip_address', full_name='graph_description.IpConnection.dst_ip_address', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='protocol', full_name='graph_description.IpConnection.protocol', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='created_timestamp', full_name='graph_description.IpConnection.created_timestamp', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='terminated_timestamp', full_name='graph_description.IpConnection.terminated_timestamp', index=5,
      number=6, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='last_seen_timestamp', full_name='graph_description.IpConnection.last_seen_timestamp', index=6,
      number=7, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='state', full_name='graph_description.IpConnection.state', index=7,
      number=8, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1372,
  serialized_end=1571,
)


_NETWORKCONNECTION = _descriptor.Descriptor(
  name='NetworkConnection',
  full_name='graph_description.NetworkConnection',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='node_key', full_name='graph_description.NetworkConnection.node_key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='src_ip_address', full_name='graph_description.NetworkConnection.src_ip_address', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='dst_ip_address', full_name='graph_description.NetworkConnection.dst_ip_address', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='protocol', full_name='graph_description.NetworkConnection.protocol', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='src_port', full_name='graph_description.NetworkConnection.src_port', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='dst_port', full_name='graph_description.NetworkConnection.dst_port', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='created_timestamp', full_name='graph_description.NetworkConnection.created_timestamp', index=6,
      number=7, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='terminated_timestamp', full_name='graph_description.NetworkConnection.terminated_timestamp', index=7,
      number=8, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='last_seen_timestamp', full_name='graph_description.NetworkConnection.last_seen_timestamp', index=8,
      number=9, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='state', full_name='graph_description.NetworkConnection.state', index=9,
      number=10, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1574,
  serialized_end=1814,
)


_IPPORT = _descriptor.Descriptor(
  name='IpPort',
  full_name='graph_description.IpPort',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='node_key', full_name='graph_description.IpPort.node_key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='ip_address', full_name='graph_description.IpPort.ip_address', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='port', full_name='graph_description.IpPort.port', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='protocol', full_name='graph_description.IpPort.protocol', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1816,
  serialized_end=1894,
)


_PROCESSOUTBOUNDCONNECTION = _descriptor.Descriptor(
  name='ProcessOutboundConnection',
  full_name='graph_description.ProcessOutboundConnection',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='node_key', full_name='graph_description.ProcessOutboundConnection.node_key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='asset_id', full_name='graph_description.ProcessOutboundConnection.asset_id', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='hostname', full_name='graph_description.ProcessOutboundConnection.hostname', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='state', full_name='graph_description.ProcessOutboundConnection.state', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='created_timestamp', full_name='graph_description.ProcessOutboundConnection.created_timestamp', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='terminated_timestamp', full_name='graph_description.ProcessOutboundConnection.terminated_timestamp', index=5,
      number=6, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='last_seen_timestamp', full_name='graph_description.ProcessOutboundConnection.last_seen_timestamp', index=6,
      number=7, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='port', full_name='graph_description.ProcessOutboundConnection.port', index=7,
      number=8, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='ip_address', full_name='graph_description.ProcessOutboundConnection.ip_address', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='protocol', full_name='graph_description.ProcessOutboundConnection.protocol', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1897,
  serialized_end=2191,
)


_PROCESSINBOUNDCONNECTION = _descriptor.Descriptor(
  name='ProcessInboundConnection',
  full_name='graph_description.ProcessInboundConnection',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='node_key', full_name='graph_description.ProcessInboundConnection.node_key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='asset_id', full_name='graph_description.ProcessInboundConnection.asset_id', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='hostname', full_name='graph_description.ProcessInboundConnection.hostname', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='state', full_name='graph_description.ProcessInboundConnection.state', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='created_timestamp', full_name='graph_description.ProcessInboundConnection.created_timestamp', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='terminated_timestamp', full_name='graph_description.ProcessInboundConnection.terminated_timestamp', index=5,
      number=6, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='last_seen_timestamp', full_name='graph_description.ProcessInboundConnection.last_seen_timestamp', index=6,
      number=7, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='port', full_name='graph_description.ProcessInboundConnection.port', index=7,
      number=8, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='ip_address', full_name='graph_description.ProcessInboundConnection.ip_address', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='protocol', full_name='graph_description.ProcessInboundConnection.protocol', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2194,
  serialized_end=2487,
)


_PROCESS = _descriptor.Descriptor(
  name='Process',
  full_name='graph_description.Process',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='node_key', full_name='graph_description.Process.node_key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='asset_id', full_name='graph_description.Process.asset_id', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='hostname', full_name='graph_description.Process.hostname', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='state', full_name='graph_description.Process.state', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='process_id', full_name='graph_description.Process.process_id', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='process_guid', full_name='graph_description.Process.process_guid', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='created_timestamp', full_name='graph_description.Process.created_timestamp', index=6,
      number=7, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='terminated_timestamp', full_name='graph_description.Process.terminated_timestamp', index=7,
      number=8, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='last_seen_timestamp', full_name='graph_description.Process.last_seen_timestamp', index=8,
      number=9, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='process_name', full_name='graph_description.Process.process_name', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='process_command_line', full_name='graph_description.Process.process_command_line', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='operating_system', full_name='graph_description.Process.operating_system', index=11,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2490,
  serialized_end=2834,
)


_FILE = _descriptor.Descriptor(
  name='File',
  full_name='graph_description.File',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='node_key', full_name='graph_description.File.node_key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='asset_id', full_name='graph_description.File.asset_id', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='hostname', full_name='graph_description.File.hostname', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='state', full_name='graph_description.File.state', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='created_timestamp', full_name='graph_description.File.created_timestamp', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='deleted_timestamp', full_name='graph_description.File.deleted_timestamp', index=5,
      number=6, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='last_seen_timestamp', full_name='graph_description.File.last_seen_timestamp', index=6,
      number=7, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='file_name', full_name='graph_description.File.file_name', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='file_path', full_name='graph_description.File.file_path', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='file_extension', full_name='graph_description.File.file_extension', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='file_mime_type', full_name='graph_description.File.file_mime_type', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='file_size', full_name='graph_description.File.file_size', index=11,
      number=12, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='file_version', full_name='graph_description.File.file_version', index=12,
      number=13, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='file_description', full_name='graph_description.File.file_description', index=13,
      number=14, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='file_product', full_name='graph_description.File.file_product', index=14,
      number=15, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='file_company', full_name='graph_description.File.file_company', index=15,
      number=16, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='file_directory', full_name='graph_description.File.file_directory', index=16,
      number=17, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='file_inode', full_name='graph_description.File.file_inode', index=17,
      number=18, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='file_hard_links', full_name='graph_description.File.file_hard_links', index=18,
      number=19, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='md5_hash', full_name='graph_description.File.md5_hash', index=19,
      number=20, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='sha1_hash', full_name='graph_description.File.sha1_hash', index=20,
      number=21, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='sha256_hash', full_name='graph_description.File.sha256_hash', index=21,
      number=22, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2837,
  serialized_end=3379,
)


_IPADDRESS = _descriptor.Descriptor(
  name='IpAddress',
  full_name='graph_description.IpAddress',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='node_key', full_name='graph_description.IpAddress.node_key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='ip_address', full_name='graph_description.IpAddress.ip_address', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='first_seen_timestamp', full_name='graph_description.IpAddress.first_seen_timestamp', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='last_seen_timestamp', full_name='graph_description.IpAddress.last_seen_timestamp', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3381,
  serialized_end=3489,
)


_NODEPROPERTY = _descriptor.Descriptor(
  name='NodeProperty',
  full_name='graph_description.NodeProperty',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='intprop', full_name='graph_description.NodeProperty.intprop', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='uintprop', full_name='graph_description.NodeProperty.uintprop', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='strprop', full_name='graph_description.NodeProperty.strprop', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='property', full_name='graph_description.NodeProperty.property',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=3491,
  serialized_end=3575,
)


_DYNAMICNODE_PROPERTIESENTRY = _descriptor.Descriptor(
  name='PropertiesEntry',
  full_name='graph_description.DynamicNode.PropertiesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='graph_description.DynamicNode.PropertiesEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='value', full_name='graph_description.DynamicNode.PropertiesEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=_descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('8\001')),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3910,
  serialized_end=3992,
)

_DYNAMICNODE = _descriptor.Descriptor(
  name='DynamicNode',
  full_name='graph_description.DynamicNode',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='properties', full_name='graph_description.DynamicNode.properties', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='node_key', full_name='graph_description.DynamicNode.node_key', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='node_type', full_name='graph_description.DynamicNode.node_type', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='seen_at', full_name='graph_description.DynamicNode.seen_at', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='asset_id', full_name='graph_description.DynamicNode.asset_id', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='hostname', full_name='graph_description.DynamicNode.hostname', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='host_ip', full_name='graph_description.DynamicNode.host_ip', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='id_strategy', full_name='graph_description.DynamicNode.id_strategy', index=7,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_DYNAMICNODE_PROPERTIESENTRY, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3578,
  serialized_end=3992,
)


_EDGE = _descriptor.Descriptor(
  name='Edge',
  full_name='graph_description.Edge',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='from', full_name='graph_description.Edge.from', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='to', full_name='graph_description.Edge.to', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='edgeName', full_name='graph_description.Edge.edgeName', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3994,
  serialized_end=4044,
)


_EDGELIST = _descriptor.Descriptor(
  name='EdgeList',
  full_name='graph_description.EdgeList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='edges', full_name='graph_description.EdgeList.edges', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4046,
  serialized_end=4096,
)


_GRAPH_NODESENTRY = _descriptor.Descriptor(
  name='NodesEntry',
  full_name='graph_description.Graph.NodesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='graph_description.Graph.NodesEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='value', full_name='graph_description.Graph.NodesEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=_descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('8\001')),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4231,
  serialized_end=4300,
)

_GRAPH_EDGESENTRY = _descriptor.Descriptor(
  name='EdgesEntry',
  full_name='graph_description.Graph.EdgesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='graph_description.Graph.EdgesEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='value', full_name='graph_description.Graph.EdgesEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=_descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('8\001')),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4302,
  serialized_end=4375,
)

_GRAPH = _descriptor.Descriptor(
  name='Graph',
  full_name='graph_description.Graph',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='nodes', full_name='graph_description.Graph.nodes', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='edges', full_name='graph_description.Graph.edges', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='graph_description.Graph.timestamp', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_GRAPH_NODESENTRY, _GRAPH_EDGESENTRY, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4099,
  serialized_end=4375,
)


_GENERATEDSUBGRAPHS = _descriptor.Descriptor(
  name='GeneratedSubgraphs',
  full_name='graph_description.GeneratedSubgraphs',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='subgraphs', full_name='graph_description.GeneratedSubgraphs.subgraphs', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4377,
  serialized_end=4442,
)

_IDSTRATEGY.fields_by_name['session'].message_type = _SESSION
_IDSTRATEGY.fields_by_name['static'].message_type = _STATIC
_IDSTRATEGY.oneofs_by_name['strategy'].fields.append(
  _IDSTRATEGY.fields_by_name['session'])
_IDSTRATEGY.fields_by_name['session'].containing_oneof = _IDSTRATEGY.oneofs_by_name['strategy']
_IDSTRATEGY.oneofs_by_name['strategy'].fields.append(
  _IDSTRATEGY.fields_by_name['static'])
_IDSTRATEGY.fields_by_name['static'].containing_oneof = _IDSTRATEGY.oneofs_by_name['strategy']
_HOST.oneofs_by_name['host_id'].fields.append(
  _HOST.fields_by_name['hostname'])
_HOST.fields_by_name['hostname'].containing_oneof = _HOST.oneofs_by_name['host_id']
_HOST.oneofs_by_name['host_id'].fields.append(
  _HOST.fields_by_name['asset_id'])
_HOST.fields_by_name['asset_id'].containing_oneof = _HOST.oneofs_by_name['host_id']
_NODE.fields_by_name['asset_node'].message_type = _ASSET
_NODE.fields_by_name['process_node'].message_type = _PROCESS
_NODE.fields_by_name['file_node'].message_type = _FILE
_NODE.fields_by_name['ip_address_node'].message_type = _IPADDRESS
_NODE.fields_by_name['process_outbound_connection_node'].message_type = _PROCESSOUTBOUNDCONNECTION
_NODE.fields_by_name['process_inbound_connection_node'].message_type = _PROCESSINBOUNDCONNECTION
_NODE.fields_by_name['ip_port_node'].message_type = _IPPORT
_NODE.fields_by_name['network_connection_node'].message_type = _NETWORKCONNECTION
_NODE.fields_by_name['ip_connection_node'].message_type = _IPCONNECTION
_NODE.fields_by_name['dynamic_node'].message_type = _DYNAMICNODE
_NODE.oneofs_by_name['which_node'].fields.append(
  _NODE.fields_by_name['asset_node'])
_NODE.fields_by_name['asset_node'].containing_oneof = _NODE.oneofs_by_name['which_node']
_NODE.oneofs_by_name['which_node'].fields.append(
  _NODE.fields_by_name['process_node'])
_NODE.fields_by_name['process_node'].containing_oneof = _NODE.oneofs_by_name['which_node']
_NODE.oneofs_by_name['which_node'].fields.append(
  _NODE.fields_by_name['file_node'])
_NODE.fields_by_name['file_node'].containing_oneof = _NODE.oneofs_by_name['which_node']
_NODE.oneofs_by_name['which_node'].fields.append(
  _NODE.fields_by_name['ip_address_node'])
_NODE.fields_by_name['ip_address_node'].containing_oneof = _NODE.oneofs_by_name['which_node']
_NODE.oneofs_by_name['which_node'].fields.append(
  _NODE.fields_by_name['process_outbound_connection_node'])
_NODE.fields_by_name['process_outbound_connection_node'].containing_oneof = _NODE.oneofs_by_name['which_node']
_NODE.oneofs_by_name['which_node'].fields.append(
  _NODE.fields_by_name['process_inbound_connection_node'])
_NODE.fields_by_name['process_inbound_connection_node'].containing_oneof = _NODE.oneofs_by_name['which_node']
_NODE.oneofs_by_name['which_node'].fields.append(
  _NODE.fields_by_name['ip_port_node'])
_NODE.fields_by_name['ip_port_node'].containing_oneof = _NODE.oneofs_by_name['which_node']
_NODE.oneofs_by_name['which_node'].fields.append(
  _NODE.fields_by_name['network_connection_node'])
_NODE.fields_by_name['network_connection_node'].containing_oneof = _NODE.oneofs_by_name['which_node']
_NODE.oneofs_by_name['which_node'].fields.append(
  _NODE.fields_by_name['ip_connection_node'])
_NODE.fields_by_name['ip_connection_node'].containing_oneof = _NODE.oneofs_by_name['which_node']
_NODE.oneofs_by_name['which_node'].fields.append(
  _NODE.fields_by_name['dynamic_node'])
_NODE.fields_by_name['dynamic_node'].containing_oneof = _NODE.oneofs_by_name['which_node']
_ASSET.fields_by_name['asset_id'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_ASSET.fields_by_name['hostname'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_ASSET.fields_by_name['mac_address'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_PROCESSOUTBOUNDCONNECTION.fields_by_name['asset_id'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_PROCESSOUTBOUNDCONNECTION.fields_by_name['hostname'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_PROCESSINBOUNDCONNECTION.fields_by_name['asset_id'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_PROCESSINBOUNDCONNECTION.fields_by_name['hostname'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_PROCESS.fields_by_name['asset_id'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_PROCESS.fields_by_name['hostname'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_FILE.fields_by_name['asset_id'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_FILE.fields_by_name['hostname'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_NODEPROPERTY.oneofs_by_name['property'].fields.append(
  _NODEPROPERTY.fields_by_name['intprop'])
_NODEPROPERTY.fields_by_name['intprop'].containing_oneof = _NODEPROPERTY.oneofs_by_name['property']
_NODEPROPERTY.oneofs_by_name['property'].fields.append(
  _NODEPROPERTY.fields_by_name['uintprop'])
_NODEPROPERTY.fields_by_name['uintprop'].containing_oneof = _NODEPROPERTY.oneofs_by_name['property']
_NODEPROPERTY.oneofs_by_name['property'].fields.append(
  _NODEPROPERTY.fields_by_name['strprop'])
_NODEPROPERTY.fields_by_name['strprop'].containing_oneof = _NODEPROPERTY.oneofs_by_name['property']
_DYNAMICNODE_PROPERTIESENTRY.fields_by_name['value'].message_type = _NODEPROPERTY
_DYNAMICNODE_PROPERTIESENTRY.containing_type = _DYNAMICNODE
_DYNAMICNODE.fields_by_name['properties'].message_type = _DYNAMICNODE_PROPERTIESENTRY
_DYNAMICNODE.fields_by_name['asset_id'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_DYNAMICNODE.fields_by_name['hostname'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_DYNAMICNODE.fields_by_name['host_ip'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_DYNAMICNODE.fields_by_name['id_strategy'].message_type = _IDSTRATEGY
_EDGELIST.fields_by_name['edges'].message_type = _EDGE
_GRAPH_NODESENTRY.fields_by_name['value'].message_type = _NODE
_GRAPH_NODESENTRY.containing_type = _GRAPH
_GRAPH_EDGESENTRY.fields_by_name['value'].message_type = _EDGELIST
_GRAPH_EDGESENTRY.containing_type = _GRAPH
_GRAPH.fields_by_name['nodes'].message_type = _GRAPH_NODESENTRY
_GRAPH.fields_by_name['edges'].message_type = _GRAPH_EDGESENTRY
_GENERATEDSUBGRAPHS.fields_by_name['subgraphs'].message_type = _GRAPH
DESCRIPTOR.message_types_by_name['Session'] = _SESSION
DESCRIPTOR.message_types_by_name['Static'] = _STATIC
DESCRIPTOR.message_types_by_name['IdStrategy'] = _IDSTRATEGY
DESCRIPTOR.message_types_by_name['Host'] = _HOST
DESCRIPTOR.message_types_by_name['Node'] = _NODE
DESCRIPTOR.message_types_by_name['Asset'] = _ASSET
DESCRIPTOR.message_types_by_name['IpConnection'] = _IPCONNECTION
DESCRIPTOR.message_types_by_name['NetworkConnection'] = _NETWORKCONNECTION
DESCRIPTOR.message_types_by_name['IpPort'] = _IPPORT
DESCRIPTOR.message_types_by_name['ProcessOutboundConnection'] = _PROCESSOUTBOUNDCONNECTION
DESCRIPTOR.message_types_by_name['ProcessInboundConnection'] = _PROCESSINBOUNDCONNECTION
DESCRIPTOR.message_types_by_name['Process'] = _PROCESS
DESCRIPTOR.message_types_by_name['File'] = _FILE
DESCRIPTOR.message_types_by_name['IpAddress'] = _IPADDRESS
DESCRIPTOR.message_types_by_name['NodeProperty'] = _NODEPROPERTY
DESCRIPTOR.message_types_by_name['DynamicNode'] = _DYNAMICNODE
DESCRIPTOR.message_types_by_name['Edge'] = _EDGE
DESCRIPTOR.message_types_by_name['EdgeList'] = _EDGELIST
DESCRIPTOR.message_types_by_name['Graph'] = _GRAPH
DESCRIPTOR.message_types_by_name['GeneratedSubgraphs'] = _GENERATEDSUBGRAPHS

Session = _reflection.GeneratedProtocolMessageType('Session', (_message.Message,), dict(
  DESCRIPTOR = _SESSION,
  __module__ = 'graph_description_pb2'
  # @@protoc_insertion_point(class_scope:graph_description.Session)
  ))
_sym_db.RegisterMessage(Session)

Static = _reflection.GeneratedProtocolMessageType('Static', (_message.Message,), dict(
  DESCRIPTOR = _STATIC,
  __module__ = 'graph_description_pb2'
  # @@protoc_insertion_point(class_scope:graph_description.Static)
  ))
_sym_db.RegisterMessage(Static)

IdStrategy = _reflection.GeneratedProtocolMessageType('IdStrategy', (_message.Message,), dict(
  DESCRIPTOR = _IDSTRATEGY,
  __module__ = 'graph_description_pb2'
  # @@protoc_insertion_point(class_scope:graph_description.IdStrategy)
  ))
_sym_db.RegisterMessage(IdStrategy)

Host = _reflection.GeneratedProtocolMessageType('Host', (_message.Message,), dict(
  DESCRIPTOR = _HOST,
  __module__ = 'graph_description_pb2'
  # @@protoc_insertion_point(class_scope:graph_description.Host)
  ))
_sym_db.RegisterMessage(Host)

Node = _reflection.GeneratedProtocolMessageType('Node', (_message.Message,), dict(
  DESCRIPTOR = _NODE,
  __module__ = 'graph_description_pb2'
  # @@protoc_insertion_point(class_scope:graph_description.Node)
  ))
_sym_db.RegisterMessage(Node)

Asset = _reflection.GeneratedProtocolMessageType('Asset', (_message.Message,), dict(
  DESCRIPTOR = _ASSET,
  __module__ = 'graph_description_pb2'
  # @@protoc_insertion_point(class_scope:graph_description.Asset)
  ))
_sym_db.RegisterMessage(Asset)

IpConnection = _reflection.GeneratedProtocolMessageType('IpConnection', (_message.Message,), dict(
  DESCRIPTOR = _IPCONNECTION,
  __module__ = 'graph_description_pb2'
  # @@protoc_insertion_point(class_scope:graph_description.IpConnection)
  ))
_sym_db.RegisterMessage(IpConnection)

NetworkConnection = _reflection.GeneratedProtocolMessageType('NetworkConnection', (_message.Message,), dict(
  DESCRIPTOR = _NETWORKCONNECTION,
  __module__ = 'graph_description_pb2'
  # @@protoc_insertion_point(class_scope:graph_description.NetworkConnection)
  ))
_sym_db.RegisterMessage(NetworkConnection)

IpPort = _reflection.GeneratedProtocolMessageType('IpPort', (_message.Message,), dict(
  DESCRIPTOR = _IPPORT,
  __module__ = 'graph_description_pb2'
  # @@protoc_insertion_point(class_scope:graph_description.IpPort)
  ))
_sym_db.RegisterMessage(IpPort)

ProcessOutboundConnection = _reflection.GeneratedProtocolMessageType('ProcessOutboundConnection', (_message.Message,), dict(
  DESCRIPTOR = _PROCESSOUTBOUNDCONNECTION,
  __module__ = 'graph_description_pb2'
  # @@protoc_insertion_point(class_scope:graph_description.ProcessOutboundConnection)
  ))
_sym_db.RegisterMessage(ProcessOutboundConnection)

ProcessInboundConnection = _reflection.GeneratedProtocolMessageType('ProcessInboundConnection', (_message.Message,), dict(
  DESCRIPTOR = _PROCESSINBOUNDCONNECTION,
  __module__ = 'graph_description_pb2'
  # @@protoc_insertion_point(class_scope:graph_description.ProcessInboundConnection)
  ))
_sym_db.RegisterMessage(ProcessInboundConnection)

Process = _reflection.GeneratedProtocolMessageType('Process', (_message.Message,), dict(
  DESCRIPTOR = _PROCESS,
  __module__ = 'graph_description_pb2'
  # @@protoc_insertion_point(class_scope:graph_description.Process)
  ))
_sym_db.RegisterMessage(Process)

File = _reflection.GeneratedProtocolMessageType('File', (_message.Message,), dict(
  DESCRIPTOR = _FILE,
  __module__ = 'graph_description_pb2'
  # @@protoc_insertion_point(class_scope:graph_description.File)
  ))
_sym_db.RegisterMessage(File)

IpAddress = _reflection.GeneratedProtocolMessageType('IpAddress', (_message.Message,), dict(
  DESCRIPTOR = _IPADDRESS,
  __module__ = 'graph_description_pb2'
  # @@protoc_insertion_point(class_scope:graph_description.IpAddress)
  ))
_sym_db.RegisterMessage(IpAddress)

NodeProperty = _reflection.GeneratedProtocolMessageType('NodeProperty', (_message.Message,), dict(
  DESCRIPTOR = _NODEPROPERTY,
  __module__ = 'graph_description_pb2'
  # @@protoc_insertion_point(class_scope:graph_description.NodeProperty)
  ))
_sym_db.RegisterMessage(NodeProperty)

DynamicNode = _reflection.GeneratedProtocolMessageType('DynamicNode', (_message.Message,), dict(

  PropertiesEntry = _reflection.GeneratedProtocolMessageType('PropertiesEntry', (_message.Message,), dict(
    DESCRIPTOR = _DYNAMICNODE_PROPERTIESENTRY,
    __module__ = 'graph_description_pb2'
    # @@protoc_insertion_point(class_scope:graph_description.DynamicNode.PropertiesEntry)
    ))
  ,
  DESCRIPTOR = _DYNAMICNODE,
  __module__ = 'graph_description_pb2'
  # @@protoc_insertion_point(class_scope:graph_description.DynamicNode)
  ))
_sym_db.RegisterMessage(DynamicNode)
_sym_db.RegisterMessage(DynamicNode.PropertiesEntry)

Edge = _reflection.GeneratedProtocolMessageType('Edge', (_message.Message,), dict(
  DESCRIPTOR = _EDGE,
  __module__ = 'graph_description_pb2'
  # @@protoc_insertion_point(class_scope:graph_description.Edge)
  ))
_sym_db.RegisterMessage(Edge)

EdgeList = _reflection.GeneratedProtocolMessageType('EdgeList', (_message.Message,), dict(
  DESCRIPTOR = _EDGELIST,
  __module__ = 'graph_description_pb2'
  # @@protoc_insertion_point(class_scope:graph_description.EdgeList)
  ))
_sym_db.RegisterMessage(EdgeList)

Graph = _reflection.GeneratedProtocolMessageType('Graph', (_message.Message,), dict(

  NodesEntry = _reflection.GeneratedProtocolMessageType('NodesEntry', (_message.Message,), dict(
    DESCRIPTOR = _GRAPH_NODESENTRY,
    __module__ = 'graph_description_pb2'
    # @@protoc_insertion_point(class_scope:graph_description.Graph.NodesEntry)
    ))
  ,

  EdgesEntry = _reflection.GeneratedProtocolMessageType('EdgesEntry', (_message.Message,), dict(
    DESCRIPTOR = _GRAPH_EDGESENTRY,
    __module__ = 'graph_description_pb2'
    # @@protoc_insertion_point(class_scope:graph_description.Graph.EdgesEntry)
    ))
  ,
  DESCRIPTOR = _GRAPH,
  __module__ = 'graph_description_pb2'
  # @@protoc_insertion_point(class_scope:graph_description.Graph)
  ))
_sym_db.RegisterMessage(Graph)
_sym_db.RegisterMessage(Graph.NodesEntry)
_sym_db.RegisterMessage(Graph.EdgesEntry)

GeneratedSubgraphs = _reflection.GeneratedProtocolMessageType('GeneratedSubgraphs', (_message.Message,), dict(
  DESCRIPTOR = _GENERATEDSUBGRAPHS,
  __module__ = 'graph_description_pb2'
  # @@protoc_insertion_point(class_scope:graph_description.GeneratedSubgraphs)
  ))
_sym_db.RegisterMessage(GeneratedSubgraphs)


_DYNAMICNODE_PROPERTIESENTRY.has_options = True
_DYNAMICNODE_PROPERTIESENTRY._options = _descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('8\001'))
_GRAPH_NODESENTRY.has_options = True
_GRAPH_NODESENTRY._options = _descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('8\001'))
_GRAPH_EDGESENTRY.has_options = True
_GRAPH_EDGESENTRY._options = _descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('8\001'))
# @@protoc_insertion_point(module_scope)
